@@ -105,8 +105,6 @@ static gboolean   xfce_volume_button_button_press_event   (GtkWidget
                                                            GdkEventButton        *event);
 static gboolean   xfce_volume_button_scroll_event         (GtkWidget             *widget,
                                                            GdkEventScroll        *event);
-static void       xfce_volume_button_volume_changed       (XfceVolumeButton      *button,
-                                                           gdouble                volume);
 static void       xfce_volume_button_update_icons         (XfceVolumeButton      *button,
                                                            GtkIconTheme          *icon_theme);
 static void       xfce_volume_button_toggled              (GtkToggleButton       *toggle_button);
@@ -125,15 +123,6 @@ static gboolean   xfce_volume_button_dock_grab_broken     (XfceVolumeButton
 
 
 
-struct _XfceVolumeButtonClass
-{
-  GtkToggleButtonClass __parent__;
-
-  /* Signals */
-  void (*volume_changed) (XfceVolumeButton *button,
-                          gdouble           volume);
-};
-
 struct _XfceVolumeButton
 {
   GtkToggleButton      __parent__;
@@ -157,9 +146,6 @@ struct _XfceVolumeButton
   /* Icon size currently used */
   gint                 icon_size;
 
-  /* Array of preloaded icons */
-  GdkPixbuf          **pixbufs;
-
   /* Track label used in tooltip */
   gchar               *track_label;
 
@@ -199,8 +185,6 @@ xfce_volume_button_class_init (XfceVolumeButtonClass *klass)
   gtk_toggle_button_class = GTK_TOGGLE_BUTTON_CLASS (klass);
   gtk_toggle_button_class->toggled = xfce_volume_button_toggled;
 
-  klass->volume_changed = xfce_volume_button_volume_changed;
-
   g_object_class_install_property (gobject_class,
                                    PROP_TRACK_LABEL,
                                    g_param_spec_string ("track-label",
@@ -246,7 +230,7 @@ xfce_volume_button_class_init (XfceVolumeButtonClass *klass)
   button_signals[VOLUME_CHANGED] = g_signal_new ("volume-changed",
                                                  G_TYPE_FROM_CLASS (klass),
                                                  G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION,
-                                                 G_STRUCT_OFFSET (XfceVolumeButtonClass, volume_changed),
+                                                 0,
                                                  NULL, 
                                                  NULL,
                                                  g_cclosure_marshal_VOID__DOUBLE,
@@ -273,9 +257,6 @@ xfce_volume_button_init (XfceVolumeButton *button)
   /* Default position is floating horizontal */
   button->screen_position = XFCE_SCREEN_POSITION_FLOATING_H;
 
-  /* Allocate array for preloaded icons */
-  button->pixbufs = g_new0 (GdkPixbuf*, G_N_ELEMENTS (icons)-1);
-
   /* Create adjustment for the button (from 0.0 to 1.0 in 5% steps) */
   button->adjustment = gtk_adjustment_new (0.0, 0.0, 1.0, 0.01, 0.05, 0.0);
 
@@ -286,7 +267,7 @@ xfce_volume_button_init (XfceVolumeButton *button)
   button->is_muted = TRUE;
 
   /* Create a new scaled image for the button icon */
-  button->image = xfce_panel_image_new ();
+  button->image = gtk_image_new ();
   gtk_container_add (GTK_CONTAINER (button), button->image);
   gtk_widget_show (button->image);
 
@@ -319,8 +300,6 @@ xfce_volume_button_dispose (GObject *object)
 static void
 xfce_volume_button_finalize (GObject *object)
 {
-  guint i;
-
   XfceVolumeButton *button = XFCE_VOLUME_BUTTON (object);
 
   if (button->dock != NULL)
@@ -329,12 +308,6 @@ xfce_volume_button_finalize (GObject *object)
       button->dock = NULL;
     }
 
-  /* Free pre-allocated icon pixbufs */
-  for (i = 0; i < G_N_ELEMENTS (icons)-1; ++i)
-    if (GDK_IS_PIXBUF (button->pixbufs[i]))
-      g_object_unref (G_OBJECT (button->pixbufs[i]));
-  g_free (button->pixbufs);
-
   if (button->track_label != NULL)
     {
       g_free (button->track_label);
@@ -442,7 +415,7 @@ static void xfce_volume_button_get_property (GObject      *object,
 GtkWidget*
 xfce_volume_button_new (void)
 {
-  return g_object_new (TYPE_XFCE_VOLUME_BUTTON, NULL);
+  return g_object_new (XFCE_TYPE_VOLUME_BUTTON, NULL);
 }
 
 
@@ -558,31 +531,12 @@ xfce_volume_button_grab_input (XfceVolumeButton *button)
   GtkWidget        *dock = button->dock;
   GdkWindow        *window = gtk_widget_get_window (dock);
   GdkDisplay       *display = gtk_widget_get_display (dock);
-#if GTK_CHECK_VERSION(3, 20, 0)
   GdkSeat          *seat = gdk_display_get_default_seat (display);
-#else
-  GdkDeviceManager *device_manager = gdk_display_get_device_manager (display);
-  GdkDevice        *pointer = gdk_device_manager_get_client_pointer (device_manager);
-  GdkDevice        *keyboard = gdk_device_get_associated_device (pointer);
-#endif
 
   gtk_grab_add (dock);
 
-#if GTK_CHECK_VERSION(3, 20, 0)
   if (gdk_seat_grab (seat, window, GDK_SEAT_CAPABILITY_ALL, TRUE, NULL, NULL, NULL, NULL) != GDK_GRAB_SUCCESS)
     goto fail_remove_grab;
-#else
-  if (gdk_device_grab (pointer, window, GDK_OWNERSHIP_WINDOW, TRUE, GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK |
-      GDK_POINTER_MOTION_MASK | GDK_SCROLL_MASK, NULL, GDK_CURRENT_TIME) != GDK_GRAB_SUCCESS)
-    goto fail_remove_grab;
-
-  if (gdk_device_grab (keyboard, window, GDK_OWNERSHIP_WINDOW, TRUE, GDK_KEY_PRESS | GDK_KEY_RELEASE, NULL,
-      GDK_CURRENT_TIME) != GDK_GRAB_SUCCESS)
-    {
-      gdk_device_ungrab (pointer, GDK_CURRENT_TIME);
-      goto fail_remove_grab;
-    }
-#endif
 
   return TRUE;
 
@@ -598,20 +552,9 @@ xfce_volume_button_ungrab_input (XfceVolumeButton *button)
 {
   GtkWidget        *dock = button->dock;
   GdkDisplay       *display = gtk_widget_get_display (dock);
-#if GTK_CHECK_VERSION(3, 20, 0)
   GdkSeat          *seat = gdk_display_get_default_seat (display);
-#else
-  GdkDeviceManager *device_manager = gdk_display_get_device_manager (display);
-  GdkDevice        *pointer = gdk_device_manager_get_client_pointer (device_manager);
-  GdkDevice        *keyboard = gdk_device_get_associated_device (pointer);
-#endif
 
-#if GTK_CHECK_VERSION(3, 20, 0)
   gdk_seat_ungrab (seat);
-#else
-  gdk_device_ungrab (pointer, GDK_CURRENT_TIME);
-  gdk_device_ungrab (keyboard, GDK_CURRENT_TIME);
-#endif
 
   gtk_grab_remove (dock);
 }
@@ -624,9 +567,9 @@ xfce_volume_button_popup_dock (XfceVolumeButton *button)
   GtkWidget       *button_widget = GTK_WIDGET (button);
   GtkOrientation   orientation;
   GtkRequisition   dock_requisition;
-  GdkScreen       *screen;
+  GdkDisplay      *display;
+  GdkMonitor      *gdkmonitor;
   GdkRectangle     monitor;
-  gint             monitor_num;
   gint             window_x;
   gint             window_y;
   GdkWindow       *window;
@@ -669,10 +612,10 @@ xfce_volume_button_popup_dock (XfceVolumeButton *button)
   y += button_allocation.y;
 
   /* Determine the geometry of the monitor containing the window containing the button */
-  screen = gtk_widget_get_screen (button_widget);
+  display = gtk_widget_get_display (button_widget);
   window = gtk_widget_get_window (GTK_WIDGET (button));
-  monitor_num = gdk_screen_get_monitor_at_window (screen, window);
-  gdk_screen_get_monitor_geometry (screen, monitor_num, &monitor);
+  gdkmonitor = gdk_display_get_monitor_at_window (display, window);
+  gdk_monitor_get_geometry (gdkmonitor, &monitor);
 
   /* Determine the position of the window containing the button */
   if (xfce_screen_position_is_top (button->screen_position))
@@ -852,15 +795,15 @@ xfce_volume_button_scroll_event (GtkWidget      *widget,
 void 
 xfce_volume_button_update (XfceVolumeButton *button)
 {
-  GdkPixbuf *pixbuf = NULL;
+  XfcePanelPlugin *plugin;
   gdouble    upper;
   gdouble    lower;
   gdouble    value;
   gdouble    range;
-  guint      i;
+  guint      i = 0;
   gchar     *tip_text;
 
-  g_return_if_fail (IS_XFCE_VOLUME_BUTTON (button));
+  g_return_if_fail (XFCE_IS_VOLUME_BUTTON (button));
 
   /* Get upper, lower bounds and current value of the adjustment */
   g_object_get (G_OBJECT (button->adjustment), "upper", &upper, "lower", &lower, "value", &value, NULL);
@@ -868,25 +811,20 @@ xfce_volume_button_update (XfceVolumeButton *button)
   /* Determine the difference between upper and lower bound (= volume range) */
   range = (upper - lower) / (G_N_ELEMENTS (icons) - 2);
 
-  if (G_UNLIKELY (!button->is_configured || button->is_muted || value < VOLUME_EPSILON))
-    {
-      /* By definition, use the first icon if the button is muted or the volume is 0% */
-      pixbuf = button->pixbufs[0];
-    }
-  else
+  /* By definition, use the first icon if the button is muted or the volume is 0% */
+  if (G_LIKELY (button->is_configured && !button->is_muted && value >= VOLUME_EPSILON))
     {
       /* Find the correct icon for the current volume */
       for (i = 1; i < G_N_ELEMENTS (icons) - 1; ++i)
         if (value <= range * i)
-          {
-            pixbuf = button->pixbufs[i];
-            break;
-          }
+          break;
     }
 
   /* Update the button icon */
-  if (G_LIKELY (pixbuf != NULL))
-    xfce_panel_image_set_from_pixbuf (XFCE_PANEL_IMAGE (button->image), pixbuf);
+  gtk_image_set_from_icon_name (GTK_IMAGE (button->image), icons[i], GTK_ICON_SIZE_BUTTON);
+  plugin = XFCE_PANEL_PLUGIN (gtk_widget_get_ancestor (GTK_WIDGET (button), XFCE_TYPE_PANEL_PLUGIN));
+  if (plugin != NULL)
+    gtk_image_set_pixel_size (GTK_IMAGE (button->image), xfce_panel_plugin_get_icon_size (plugin));
 
   /* Update the tooltip */
   if (!button->is_configured)
@@ -905,37 +843,13 @@ xfce_volume_button_update (XfceVolumeButton *button)
 
 
 
-static void
-xfce_volume_button_volume_changed (XfceVolumeButton *button,
-                                   gdouble           volume)
-{
-  /* Do nothing */
-}
-
-
-
 static void
 xfce_volume_button_update_icons (XfceVolumeButton *button,
                                  GtkIconTheme     *icon_theme)
 {
-  guint i;
-
-  g_return_if_fail (IS_XFCE_VOLUME_BUTTON (button));
+  g_return_if_fail (XFCE_IS_VOLUME_BUTTON (button));
   g_return_if_fail (GTK_IS_ICON_THEME (icon_theme));
 
-  /* Pre-load all icons */
-  for (i = 0; i < G_N_ELEMENTS (icons)-1; ++i)
-    {
-      if (GDK_IS_PIXBUF (button->pixbufs[i]))
-        g_object_unref (G_OBJECT (button->pixbufs[i]));
-
-      button->pixbufs[i] = gtk_icon_theme_load_icon (icon_theme,
-                                                     icons[i],
-                                                     button->icon_size,
-                                                     GTK_ICON_LOOKUP_USE_BUILTIN,
-                                                     NULL);
-    }
-
   /* Update the state of the button */
   xfce_volume_button_update (button);
 }
@@ -1024,7 +938,7 @@ xfce_volume_button_set_no_mute (XfceVolumeButton *button,
 {
   GValue value = { 0 };
 
-  g_return_if_fail (IS_XFCE_VOLUME_BUTTON (button));
+  g_return_if_fail (XFCE_IS_VOLUME_BUTTON (button));
 
   g_value_init (&value, G_TYPE_BOOLEAN);
   g_value_set_boolean (&value, no_mute);
@@ -1038,7 +952,7 @@ xfce_volume_button_get_no_mute (XfceVolumeButton *button)
 {
   GValue value = { 0 };
 
-  g_return_val_if_fail (IS_XFCE_VOLUME_BUTTON (button), FALSE);
+  g_return_val_if_fail (XFCE_IS_VOLUME_BUTTON (button), FALSE);
 
   g_value_init (&value, G_TYPE_BOOLEAN);
   g_object_get_property (G_OBJECT (button), "no-mute", &value);
@@ -1054,7 +968,7 @@ xfce_volume_button_set_muted (XfceVolumeButton *button,
 {
   GValue value = { 0 };
 
-  g_return_if_fail (IS_XFCE_VOLUME_BUTTON (button));
+  g_return_if_fail (XFCE_IS_VOLUME_BUTTON (button));
 
   g_value_init (&value, G_TYPE_BOOLEAN);
   g_value_set_boolean (&value, is_muted);
@@ -1068,7 +982,7 @@ xfce_volume_button_get_muted (XfceVolumeButton *button)
 {
   GValue value = { 0 };
 
-  g_return_val_if_fail (IS_XFCE_VOLUME_BUTTON (button), FALSE);
+  g_return_val_if_fail (XFCE_IS_VOLUME_BUTTON (button), FALSE);
 
   g_value_init (&value, G_TYPE_BOOLEAN);
   g_object_get_property (G_OBJECT (button), "is-muted", &value);
@@ -1082,7 +996,7 @@ void
 xfce_volume_button_set_volume (XfceVolumeButton *button,
                                gdouble           volume)
 {
-  g_return_if_fail (IS_XFCE_VOLUME_BUTTON (button));
+  g_return_if_fail (XFCE_IS_VOLUME_BUTTON (button));
 
   /* Set the value of the adjustment */
   gtk_adjustment_set_value (GTK_ADJUSTMENT (button->adjustment), volume);
@@ -1097,7 +1011,7 @@ void
 xfce_volume_button_set_icon_size (XfceVolumeButton *button,
                                   gint              size)
 {
-  g_return_if_fail (IS_XFCE_VOLUME_BUTTON (button));
+  g_return_if_fail (XFCE_IS_VOLUME_BUTTON (button));
   g_return_if_fail (size >= 0);
 
   /* Remember the icon size */
@@ -1114,7 +1028,7 @@ xfce_volume_button_set_track_label (XfceVolumeButton *button,
 {
   GValue value = { 0 };
 
-  g_return_if_fail (IS_XFCE_VOLUME_BUTTON (button));
+  g_return_if_fail (XFCE_IS_VOLUME_BUTTON (button));
 
   g_value_init (&value, G_TYPE_STRING);
   g_value_set_string (&value, track_label);
@@ -1128,7 +1042,7 @@ xfce_volume_button_get_track_label (XfceVolumeButton *button)
 {
   GValue value = { 0 };
 
-  g_return_val_if_fail (IS_XFCE_VOLUME_BUTTON (button), NULL);
+  g_return_val_if_fail (XFCE_IS_VOLUME_BUTTON (button), NULL);
 
   g_value_init (&value, G_TYPE_STRING);
   g_object_get_property (G_OBJECT (button), "track-label", &value);
@@ -1144,7 +1058,7 @@ xfce_volume_button_set_is_configured (XfceVolumeButton *button,
 {
   GValue value = { 0 };
 
-  g_return_if_fail (IS_XFCE_VOLUME_BUTTON (button));
+  g_return_if_fail (XFCE_IS_VOLUME_BUTTON (button));
 
   g_value_init (&value, G_TYPE_BOOLEAN);
   g_value_set_boolean (&value, is_configured);
@@ -1158,7 +1072,7 @@ xfce_volume_button_get_is_configured (XfceVolumeButton *button)
 {
   GValue value = { 0 };
 
-  g_return_val_if_fail (IS_XFCE_VOLUME_BUTTON (button), FALSE);
+  g_return_val_if_fail (XFCE_IS_VOLUME_BUTTON (button), FALSE);
 
   g_value_init (&value, G_TYPE_BOOLEAN);
   g_object_get_property (G_OBJECT (button), "is-configured", &value);
@@ -1174,7 +1088,7 @@ xfce_volume_button_set_screen_position (XfceVolumeButton   *button,
 {
   GValue value = { 0 };
 
-  g_return_if_fail (IS_XFCE_VOLUME_BUTTON (button));
+  g_return_if_fail (XFCE_IS_VOLUME_BUTTON (button));
 
   g_value_init (&value, XFCE_TYPE_SCREEN_POSITION);
   g_value_set_enum (&value, screen_position);
@@ -1188,7 +1102,7 @@ xfce_volume_button_get_screen_position (XfceVolumeButton *button)
 {
   GValue value = { 0 };
 
-  g_return_val_if_fail (IS_XFCE_VOLUME_BUTTON (button), FALSE);
+  g_return_val_if_fail (XFCE_IS_VOLUME_BUTTON (button), FALSE);
 
   g_value_init (&value, XFCE_TYPE_SCREEN_POSITION);
   g_object_get_property (G_OBJECT (button), "screen-position", &value);
